Update your application's privacy policy to explicitly state that information for identity verification is collected. Clearly describe the types of information collected, the specific purposes for its collection, how it is securely processed and store, how long it is retained, and user rights regarding this data. Ensure explicit user consent is obtained and that all practices comply with applicable data protection laws.